@@ -7,7 +7,7 @@ class Capec(Enum):
     probabilistic_techniques = '3'
     exploitation_of_autentication = '4'
     resource_depletion = '5'
-    exploitation_of_privilege/trust = '6'
+    exploitation_of_privilege_slash_trust = '6'
     injection = '7'
     data_structure_attacks = '8'
     data_leackage_attacks = '9'
